"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
log = logging.getLogger(__name__)


@register_command(
    extending=("geoip", "v1", "ranges"),
    module=argus_cli_module
)
def add_or_update_ranges(
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Add or update IP ranges (DEV)
    
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/geoip/v1/ranges".format()
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("geoip", "v1", "ranges"),
    module=argus_cli_module
)
def find_ranges(
    countTimeout: int = None,
    ipAddress: dict = None,
    limit: int = None,
    offset: int = None,
    includeDeleted: bool = None,
    includeFlags: int = None,
    excludeFlags: int = None,
    countryID: int = None,
    country: str = None,
    regionID: int = None,
    locationID: int = None,
    rangeID: int = None,
    startIPAddress: dict = None,
    fromIP: dict = None,
    toIP: dict = None,
    addressFamily: str = None,
    sortBy: str = None,
    startTimestamp: int = None,
    endTimestamp: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Find IP ranges (DEV)
    
    :param int countTimeout: Max wait in seconds for the count query to run. Set the value to \-1 to skip counting \(count will be returned \-1\). Set the value to 0 to execute the count query as long as the service allows\, max allowed timeout value is 30 \(seconds\)\, default value is \-1.
    :param list ipAddress: 
    :param int limit: Max number of results.
    :param int offset: Skip the first \(offset\) objects. By default\, return result from first object.
    :param bool includeDeleted: Also include deleted objects \(where implemented\)
    :param int includeFlags: Search objects with these flags set
    :param int excludeFlags: Exclude objects with these flags set
    :param list countryID: Deprecated\, use country instead
    :param list country: Only return ranges from these countries \(by country ID or two\-letter code\)
    :param list regionID: Only return ranges from these regions \(by regionID\)
    :param list locationID: Only return ranges from these locations \(by locationID\)
    :param list rangeID: Only return specific ranges \(by ID\)
    :param list startIPAddress: Only return ranges where the range start\-address matches one of these IP\-addresses
    :param dict fromIP: 
    :param dict toIP: 
    :param str addressFamily: Only return ranges for this address family range \(ipv4 or ipv6\)
    :param list sortBy: Order results by these properties \(prefix with \- to sort descending\)
    :param int startTimestamp: Search objects from this timestamp
    :param int endTimestamp: Search objects until this timestamp
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/geoip/v1/ranges/search".format()
    headers = {}

    body = body or {}
    # Only send countTimeout if the argument was provided, don't send null values
    if countTimeout is not None:
        body.update({"countTimeout": countTimeout})
    # Only send ipAddress if the argument was provided, don't send null values
    if ipAddress is not None:
        body.update({"ipAddress": ipAddress})
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        body.update({"offset": offset})
    # Only send includeDeleted if the argument was provided, don't send null values
    if includeDeleted is not None:
        body.update({"includeDeleted": includeDeleted})
    # Only send includeFlags if the argument was provided, don't send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send excludeFlags if the argument was provided, don't send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send countryID if the argument was provided, don't send null values
    if countryID is not None:
        body.update({"countryID": countryID})
    # Only send country if the argument was provided, don't send null values
    if country is not None:
        body.update({"country": country})
    # Only send regionID if the argument was provided, don't send null values
    if regionID is not None:
        body.update({"regionID": regionID})
    # Only send locationID if the argument was provided, don't send null values
    if locationID is not None:
        body.update({"locationID": locationID})
    # Only send rangeID if the argument was provided, don't send null values
    if rangeID is not None:
        body.update({"rangeID": rangeID})
    # Only send startIPAddress if the argument was provided, don't send null values
    if startIPAddress is not None:
        body.update({"startIPAddress": startIPAddress})
    # Only send fromIP if the argument was provided, don't send null values
    if fromIP is not None:
        body.update({"fromIP": fromIP})
    # Only send toIP if the argument was provided, don't send null values
    if toIP is not None:
        body.update({"toIP": toIP})
    # Only send addressFamily if the argument was provided, don't send null values
    if addressFamily is not None:
        body.update({"addressFamily": addressFamily})
    # Only send sortBy if the argument was provided, don't send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})
    # Only send startTimestamp if the argument was provided, don't send null values
    if startTimestamp is not None:
        body.update({"startTimestamp": startTimestamp})
    # Only send endTimestamp if the argument was provided, don't send null values
    if endTimestamp is not None:
        body.update({"endTimestamp": endTimestamp})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
