"""Autogenerated API"""
from argus_api.session import get_session
from typing import TYPE_CHECKING, Optional
if TYPE_CHECKING:
    from argus_api.session import ArgusAPISession


def add_region(
    id: int = None,
    flags: int = None,
    minLocationID: int = None,
    maxLocationID: int = None,
    countryCode: str = None,
    regionCode: str = None,
    regionName: str = None,
    lastModified: int = None,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """Add new region (DEV)
    
    :param int id: 
    :param int flags: 
    :param int minLocationID: 
    :param int maxLocationID: 
    :param str countryCode: The two\-letter code of the country where this region is in
    :param str regionCode: The code of the region
    :param str regionName: The name of the region
    :param int lastModified: The timestamp when this region was last modified
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/geoip/v1/region".format()

    session = api_session or get_session()
    headers = {}

    body = body or {}
    # Only send id if the argument was provided, don't send null values
    if id is not None:
        body.update({"id": id})
    # Only send flags if the argument was provided, don't send null values
    if flags is not None:
        body.update({"flags": flags})
    # Only send minLocationID if the argument was provided, don't send null values
    if minLocationID is not None:
        body.update({"minLocationID": minLocationID})
    # Only send maxLocationID if the argument was provided, don't send null values
    if maxLocationID is not None:
        body.update({"maxLocationID": maxLocationID})
    # Only send countryCode if the argument was provided, don't send null values
    if countryCode is not None:
        body.update({"countryCode": countryCode})
    # Only send regionCode if the argument was provided, don't send null values
    if regionCode is not None:
        body.update({"regionCode": regionCode})
    # Only send regionName if the argument was provided, don't send null values
    if regionName is not None:
        body.update({"regionName": regionName})
    # Only send lastModified if the argument was provided, don't send null values
    if lastModified is not None:
        body.update({"lastModified": lastModified})

    query_parameters = {}

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
